@@ -46,6 +46,16 @@ class AbstractCustomEditor(object):
         finalHeight = max(height)
         
         return finalHeight
+    
+    def set_background_color(self, background_color):        
+        if background_color not in (None, ValueLoading):
+            palette = self.palette()
+            for x in [QtGui.QPalette.Active, QtGui.QPalette.Inactive, QtGui.QPalette.Disabled]:
+                for y in [self.backgroundRole(), QtGui.QPalette.Window]:
+                    palette.setColor(x, y, background_color)
+            self.setPalette(palette)
+        else:
+            return False
           
 class CustomEditor(QtGui.QWidget, AbstractCustomEditor):
     """Base class for implementing custom editor widgets.  This class provides
